@@ -2,7 +2,7 @@ import json
 import yaml
 from yaml import CSafeLoader
 from yaml import SafeLoader
-from yaml import SafeLoader as NewSafeLoader
+from yaml.loader import SafeLoader as NewSafeLoader
 
 
 def test_yaml_load():
@@ -29,3 +29,8 @@ yaml.load("{}", yaml.SafeLoader)
 yaml.load("{}", CSafeLoader)
 yaml.load("{}", yaml.CSafeLoader)
 yaml.load("{}", NewSafeLoader)
+yaml.load("{}", Loader=SafeLoader)
+yaml.load("{}", Loader=yaml.SafeLoader)
+yaml.load("{}", Loader=CSafeLoader)
+yaml.load("{}", Loader=yaml.CSafeLoader)
+yaml.load("{}", Loader=NewSafeLoader)
