@@ -47,3 +47,13 @@ dict(map(lambda k, v: (k, v), keys, values))
 map(lambda x: x, y if y else z)
 map(lambda x: x, (y if y else z))
 map(lambda x: x, (x, y, z))
+
+# See https://github.com/astral-sh/ruff/issues/14808
+# The following should be Ok since 
+# named expressions are a syntax error inside comprehensions
+a = [1, 2, 3]
+b = map(lambda x: x, c := a)
+print(c)
+
+# Check nested as well
+map(lambda x:x, [c:=a])
