@@ -1,5 +1,5 @@
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast::{self as ast, StringLike};
 use ruff_text_size::Ranged;
 
@@ -26,8 +26,8 @@ use crate::checkers::ast::Checker;
 ///
 /// ## References
 /// - [Common Weakness Enumeration: CWE-200](https://cwe.mitre.org/data/definitions/200.html)
-#[violation]
-pub struct HardcodedBindAllInterfaces;
+#[derive(ViolationMetadata)]
+pub(crate) struct HardcodedBindAllInterfaces;
 
 impl Violation for HardcodedBindAllInterfaces {
     #[derive_message_formats]
