@@ -1,7 +1,7 @@
 use ruff_python_ast::{self as ast, Stmt};
 
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast::identifier::Identifier;
 
 use crate::checkers::ast::Checker;
@@ -30,8 +30,8 @@ use crate::checkers::ast::Checker;
 /// ## References
 /// - [PEP 257 – Docstring Conventions](https://peps.python.org/pep-0257/)
 /// - [Python documentation: Formatted string literals](https://docs.python.org/3/reference/lexical_analysis.html#f-strings)
-#[violation]
-pub struct FStringDocstring;
+#[derive(ViolationMetadata)]
+pub(crate) struct FStringDocstring;
 
 impl Violation for FStringDocstring {
     #[derive_message_formats]
