@@ -9,13 +9,13 @@ use crate::checkers::ast::Checker;
 use crate::rules::flake8_comprehensions::fixes;
 
 /// ## What it does
-/// Checks for unnecessary `list`, `reversed`, `set`, `sorted`, and `tuple`
-/// call within `list`, `set`, `sorted`, and `tuple` calls.
+/// Checks for unnecessary `list()`, `reversed()`, `set()`, `sorted()`, and
+/// `tuple()` call within `list()`, `set()`, `sorted()`, and `tuple()` calls.
 ///
 /// ## Why is this bad?
 /// It's unnecessary to double-cast or double-process iterables by wrapping
-/// the listed functions within an additional `list`, `set`, `sorted`, or
-/// `tuple` call. Doing so is redundant and can be confusing for readers.
+/// the listed functions within an additional `list()`, `set()`, `sorted()`, or
+/// `tuple()` call. Doing so is redundant and can be confusing for readers.
 ///
 /// ## Examples
 /// ```python
@@ -27,8 +27,8 @@ use crate::rules::flake8_comprehensions::fixes;
 /// list(iterable)
 /// ```
 ///
-/// This rule applies to a variety of functions, including `list`, `reversed`,
-/// `set`, `sorted`, and `tuple`. For example:
+/// This rule applies to a variety of functions, including `list()`, `reversed()`,
+/// `set()`, `sorted()`, and `tuple()`. For example:
 ///
 /// - Instead of `list(list(iterable))`, use `list(iterable)`.
 /// - Instead of `list(tuple(iterable))`, use `list(iterable)`.
@@ -57,12 +57,12 @@ impl AlwaysFixableViolation for UnnecessaryDoubleCastOrProcess {
     #[derive_message_formats]
     fn message(&self) -> String {
         let UnnecessaryDoubleCastOrProcess { inner, outer } = self;
-        format!("Unnecessary `{inner}` call within `{outer}()`")
+        format!("Unnecessary `{inner}()` call within `{outer}()`")
     }
 
     fn fix_title(&self) -> String {
         let UnnecessaryDoubleCastOrProcess { inner, .. } = self;
-        format!("Remove the inner `{inner}` call")
+        format!("Remove the inner `{inner}()` call")
     }
 }
 
