@@ -2,7 +2,7 @@ use ruff_python_ast::Expr;
 use ruff_text_size::TextRange;
 
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_semantic::Modules;
 
 use crate::checkers::ast::Checker;
@@ -45,8 +45,8 @@ use super::helpers;
 ///
 /// ## References
 /// - [Python documentation: Aware and Naive Objects](https://docs.python.org/3/library/datetime.html#aware-and-naive-objects)
-#[violation]
-pub struct CallDatetimeUtcnow;
+#[derive(ViolationMetadata)]
+pub(crate) struct CallDatetimeUtcnow;
 
 impl Violation for CallDatetimeUtcnow {
     #[derive_message_formats]
