@@ -1,7 +1,7 @@
 use ruff_python_ast::{self as ast, Expr, Stmt};
 
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast::helpers::is_const_true;
 use ruff_python_semantic::{Modules, SemanticModel};
 use ruff_text_size::Ranged;
@@ -40,8 +40,8 @@ use super::helpers;
 /// class MyModel(models.Model):
 ///     field = models.CharField(max_length=255, default="")
 /// ```
-#[violation]
-pub struct DjangoNullableModelStringField {
+#[derive(ViolationMetadata)]
+pub(crate) struct DjangoNullableModelStringField {
     field_name: String,
 }
 
