@@ -864,12 +864,12 @@ pub(crate) fn parametrize(checker: &mut Checker, call: &ExprCall) {
 
     if checker.enabled(Rule::PytestParametrizeNamesWrongType) {
         let names = if checker.settings.preview.is_enabled() {
-            call.arguments.find_argument("argnames", 0)
+            call.arguments.find_argument_value("argnames", 0)
         } else {
             call.arguments.find_positional(0)
         };
         let values = if checker.settings.preview.is_enabled() {
-            call.arguments.find_argument("argvalues", 1)
+            call.arguments.find_argument_value("argvalues", 1)
         } else {
             call.arguments.find_positional(1)
         };
@@ -879,12 +879,12 @@ pub(crate) fn parametrize(checker: &mut Checker, call: &ExprCall) {
     }
     if checker.enabled(Rule::PytestParametrizeValuesWrongType) {
         let names = if checker.settings.preview.is_enabled() {
-            call.arguments.find_argument("argnames", 0)
+            call.arguments.find_argument_value("argnames", 0)
         } else {
             call.arguments.find_positional(0)
         };
         let values = if checker.settings.preview.is_enabled() {
-            call.arguments.find_argument("argvalues", 1)
+            call.arguments.find_argument_value("argvalues", 1)
         } else {
             call.arguments.find_positional(1)
         };
@@ -894,7 +894,7 @@ pub(crate) fn parametrize(checker: &mut Checker, call: &ExprCall) {
     }
     if checker.enabled(Rule::PytestDuplicateParametrizeTestCases) {
         if let Some(values) = if checker.settings.preview.is_enabled() {
-            call.arguments.find_argument("argvalues", 1)
+            call.arguments.find_argument_value("argvalues", 1)
         } else {
             call.arguments.find_positional(1)
         } {
