@@ -98,12 +98,31 @@ fn runtime_required_decorators(
     }
 
     decorator_list.iter().any(|decorator| {
+        let expression = map_callable(&decorator.expression);
         semantic
-            .resolve_qualified_name(map_callable(&decorator.expression))
+            // First try to resolve the qualified name normally for cases like:
+            // ```python
+            // from mymodule import app
+            //
+            // @app.get(...)
+            // def test(): ...
+            //  ```
+            .resolve_qualified_name(expression)
+            // If we can't resolve the name, then try resolving the assignment
+            // in order to support cases like:
+            // ```python
+            // from fastapi import FastAPI
+            //
+            // app = FastAPI()
+            //
+            // @app.get(...)
+            // def test(): ...
+            // ```
+            .or_else(|| analyze::typing::resolve_assignment(expression, semantic))
             .is_some_and(|qualified_name| {
                 decorators
                     .iter()
-                    .any(|base_class| QualifiedName::from_dotted_name(base_class) == qualified_name)
+                    .any(|decorator| QualifiedName::from_dotted_name(decorator) == qualified_name)
             })
     })
 }
