@@ -3,7 +3,7 @@ use itertools::Itertools;
 
 use crate::fix::edits::pad;
 use ruff_diagnostics::{AlwaysFixableViolation, Diagnostic, Edit, Fix};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast::{self as ast, Arguments, Expr};
 use ruff_text_size::{Ranged, TextRange};
 
@@ -30,8 +30,8 @@ use crate::rules::flynt::helpers;
 ///
 /// ## References
 /// - [Python documentation: f-strings](https://docs.python.org/3/reference/lexical_analysis.html#f-strings)
-#[violation]
-pub struct StaticJoinToFString {
+#[derive(ViolationMetadata)]
+pub(crate) struct StaticJoinToFString {
     expression: SourceCodeSnippet,
 }
 
