@@ -5,7 +5,7 @@ use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast as ast;
 use ruff_python_ast::ParameterWithDefault;
 use ruff_python_codegen::Stylist;
-use ruff_python_semantic::analyze::class::is_metaclass;
+use ruff_python_semantic::analyze::class::{is_metaclass, IsMetaclass};
 use ruff_python_semantic::analyze::function_type;
 use ruff_python_semantic::{Scope, ScopeKind, SemanticModel};
 use ruff_text_size::Ranged;
@@ -212,13 +212,11 @@ pub(crate) fn invalid_first_argument_name(
         function_type::FunctionType::Function | function_type::FunctionType::StaticMethod => {
             return;
         }
-        function_type::FunctionType::Method => {
-            if is_metaclass(parent, semantic) {
-                FunctionType::ClassMethod
-            } else {
-                FunctionType::Method
-            }
-        }
+        function_type::FunctionType::Method => match is_metaclass(parent, semantic) {
+            IsMetaclass::Yes => FunctionType::ClassMethod,
+            IsMetaclass::No => FunctionType::Method,
+            IsMetaclass::Maybe => return,
+        },
         function_type::FunctionType::ClassMethod => FunctionType::ClassMethod,
     };
     if !checker.enabled(function_type.rule()) {
