@@ -1,5 +1,5 @@
 use ruff_diagnostics::{AlwaysFixableViolation, Diagnostic, Edit, Fix};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast::statement_visitor::{walk_stmt, StatementVisitor};
 use ruff_python_ast::{self as ast, Arguments, Expr, Stmt};
 use ruff_python_semantic::analyze::typing::find_assigned_value;
@@ -35,8 +35,8 @@ use crate::checkers::ast::Checker;
 /// for i in items:
 ///     print(i)
 /// ```
-#[violation]
-pub struct UnnecessaryListCast;
+#[derive(ViolationMetadata)]
+pub(crate) struct UnnecessaryListCast;
 
 impl AlwaysFixableViolation for UnnecessaryListCast {
     #[derive_message_formats]
