@@ -1,6 +1,6 @@
 use ruff_diagnostics::{AlwaysFixableViolation, Violation};
 use ruff_diagnostics::{Diagnostic, Edit, Fix};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_notebook::CellOffsets;
 use ruff_python_ast::PySourceType;
 use ruff_python_index::Indexer;
@@ -27,8 +27,8 @@ use crate::Locator;
 /// ```
 ///
 /// [PEP 8]: https://peps.python.org/pep-0008/#other-recommendations
-#[violation]
-pub struct MultipleStatementsOnOneLineColon;
+#[derive(ViolationMetadata)]
+pub(crate) struct MultipleStatementsOnOneLineColon;
 
 impl Violation for MultipleStatementsOnOneLineColon {
     #[derive_message_formats]
@@ -57,8 +57,8 @@ impl Violation for MultipleStatementsOnOneLineColon {
 /// ```
 ///
 /// [PEP 8]: https://peps.python.org/pep-0008/#other-recommendations
-#[violation]
-pub struct MultipleStatementsOnOneLineSemicolon;
+#[derive(ViolationMetadata)]
+pub(crate) struct MultipleStatementsOnOneLineSemicolon;
 
 impl Violation for MultipleStatementsOnOneLineSemicolon {
     #[derive_message_formats]
@@ -82,8 +82,8 @@ impl Violation for MultipleStatementsOnOneLineSemicolon {
 /// ```python
 /// do_four()
 /// ```
-#[violation]
-pub struct UselessSemicolon;
+#[derive(ViolationMetadata)]
+pub(crate) struct UselessSemicolon;
 
 impl AlwaysFixableViolation for UselessSemicolon {
     #[derive_message_formats]
