@@ -1,5 +1,5 @@
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast::{PySourceType, Stmt};
 use ruff_text_size::Ranged;
 
@@ -39,8 +39,8 @@ use crate::checkers::ast::Checker;
 /// For Jupyter notebooks, this rule checks for imports that are not at the top of a *cell*.
 ///
 /// [PEP 8]: https://peps.python.org/pep-0008/#imports
-#[violation]
-pub struct ModuleImportNotAtTopOfFile {
+#[derive(ViolationMetadata)]
+pub(crate) struct ModuleImportNotAtTopOfFile {
     source_type: PySourceType,
 }
 
