@@ -43,9 +43,9 @@ use crate::registry::Rule;
 ///
 /// [D211]: https://docs.astral.sh/ruff/rules/blank-line-before-class
 #[derive(ViolationMetadata)]
-pub(crate) struct OneBlankLineBeforeClass;
+pub(crate) struct IncorrectBlankLineBeforeClass;
 
-impl AlwaysFixableViolation for OneBlankLineBeforeClass {
+impl AlwaysFixableViolation for IncorrectBlankLineBeforeClass {
     #[derive_message_formats]
     fn message(&self) -> String {
         "1 blank line required before class docstring".to_string()
@@ -95,9 +95,9 @@ impl AlwaysFixableViolation for OneBlankLineBeforeClass {
 ///
 /// [PEP 257]: https://peps.python.org/pep-0257/
 #[derive(ViolationMetadata)]
-pub(crate) struct OneBlankLineAfterClass;
+pub(crate) struct IncorrectBlankLineAfterClass;
 
-impl AlwaysFixableViolation for OneBlankLineAfterClass {
+impl AlwaysFixableViolation for IncorrectBlankLineAfterClass {
     #[derive_message_formats]
     fn message(&self) -> String {
         "1 blank line required after class docstring".to_string()
@@ -140,7 +140,7 @@ impl AlwaysFixableViolation for OneBlankLineAfterClass {
 /// ## Options
 /// - `lint.pydocstyle.convention`
 ///
-/// [D203]: https://docs.astral.sh/ruff/rules/one-blank-line-before-class
+/// [D203]: https://docs.astral.sh/ruff/rules/incorrect-blank-line-before-class
 #[derive(ViolationMetadata)]
 pub(crate) struct BlankLineBeforeClass;
 
@@ -170,7 +170,8 @@ pub(crate) fn blank_before_after_class(checker: &mut Checker, docstring: &Docstr
         return;
     }
 
-    if checker.enabled(Rule::OneBlankLineBeforeClass) || checker.enabled(Rule::BlankLineBeforeClass)
+    if checker.enabled(Rule::IncorrectBlankLineBeforeClass)
+        || checker.enabled(Rule::BlankLineBeforeClass)
     {
         let mut lines = UniversalNewlineIterator::with_offset(
             checker.locator().slice(between_range),
@@ -201,9 +202,10 @@ pub(crate) fn blank_before_after_class(checker: &mut Checker, docstring: &Docstr
                 checker.diagnostics.push(diagnostic);
             }
         }
-        if checker.enabled(Rule::OneBlankLineBeforeClass) {
+        if checker.enabled(Rule::IncorrectBlankLineBeforeClass) {
             if blank_lines_before != 1 {
-                let mut diagnostic = Diagnostic::new(OneBlankLineBeforeClass, docstring.range());
+                let mut diagnostic =
+                    Diagnostic::new(IncorrectBlankLineBeforeClass, docstring.range());
                 // Insert one blank line before the class.
                 diagnostic.set_fix(Fix::safe_edit(Edit::replacement(
                     checker.stylist().line_ending().to_string(),
@@ -215,7 +217,7 @@ pub(crate) fn blank_before_after_class(checker: &mut Checker, docstring: &Docstr
         }
     }
 
-    if checker.enabled(Rule::OneBlankLineAfterClass) {
+    if checker.enabled(Rule::IncorrectBlankLineAfterClass) {
         let class_after_docstring_range = TextRange::new(docstring.end(), class.end());
         let class_after_docstring = checker.locator().slice(class_after_docstring_range);
         let mut lines = UniversalNewlineIterator::with_offset(
@@ -242,7 +244,8 @@ pub(crate) fn blank_before_after_class(checker: &mut Checker, docstring: &Docstr
             if let Some(next_statement) = trailing.strip_prefix(';') {
                 let indentation = indentation_at_offset(docstring.start(), checker.source())
                     .expect("Own line docstring must have indentation");
-                let mut diagnostic = Diagnostic::new(OneBlankLineAfterClass, docstring.range());
+                let mut diagnostic =
+                    Diagnostic::new(IncorrectBlankLineAfterClass, docstring.range());
                 let line_ending = checker.stylist().line_ending().as_str();
                 // We have to trim the whitespace twice, once before the semicolon above and
                 // once after the semicolon here, or we get invalid indents:
@@ -277,7 +280,7 @@ pub(crate) fn blank_before_after_class(checker: &mut Checker, docstring: &Docstr
         }
 
         if blank_lines_after != 1 {
-            let mut diagnostic = Diagnostic::new(OneBlankLineAfterClass, docstring.range());
+            let mut diagnostic = Diagnostic::new(IncorrectBlankLineAfterClass, docstring.range());
             // Insert a blank line before the class (replacing any existing lines).
             diagnostic.set_fix(Fix::safe_edit(Edit::replacement(
                 checker.stylist().line_ending().to_string(),
