@@ -1,5 +1,5 @@
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast::identifier::Identifier;
 use ruff_python_semantic::analyze::visibility::is_overload;
 
@@ -66,8 +66,8 @@ use crate::docstrings::Docstring;
 /// ## References
 /// - [PEP 257 – Docstring Conventions](https://peps.python.org/pep-0257/)
 /// - [Python documentation: `typing.overload`](https://docs.python.org/3/library/typing.html#typing.overload)
-#[violation]
-pub struct OverloadWithDocstring;
+#[derive(ViolationMetadata)]
+pub(crate) struct OverloadWithDocstring;
 
 impl Violation for OverloadWithDocstring {
     #[derive_message_formats]
