@@ -1,7 +1,7 @@
 use ruff_python_ast::Stmt;
 
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_semantic::ScopeKind;
 use ruff_text_size::Ranged;
 
@@ -22,8 +22,8 @@ use crate::checkers::ast::Checker;
 ///
 /// ## References
 /// - [Python documentation: `return`](https://docs.python.org/3/reference/simple_stmts.html#the-return-statement)
-#[violation]
-pub struct ReturnOutsideFunction;
+#[derive(ViolationMetadata)]
+pub(crate) struct ReturnOutsideFunction;
 
 impl Violation for ReturnOutsideFunction {
     #[derive_message_formats]
