@@ -1,5 +1,5 @@
 use ruff_diagnostics::{Diagnostic, Edit, Fix, FixAvailability, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_trivia::Cursor;
 use ruff_text_size::{Ranged, TextRange};
 
@@ -43,8 +43,8 @@ use crate::Locator;
 /// - [Ruff documentation](https://docs.astral.sh/ruff/configuration/#error-suppression)
 ///
 /// [preview]: https://docs.astral.sh/ruff/preview/
-#[violation]
-pub struct BlanketNOQA {
+#[derive(ViolationMetadata)]
+pub(crate) struct BlanketNOQA {
     missing_colon: bool,
     space_before_colon: bool,
     file_exemption: bool,
