@@ -1,7 +1,7 @@
 use ruff_python_ast::{self as ast, ExceptHandler, Expr};
 
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_text_size::Ranged;
 
 use crate::checkers::ast::Checker;
@@ -46,8 +46,8 @@ impl From<&ast::BoolOp> for BoolOp {
 /// except (A, B):
 ///     pass
 /// ```
-#[violation]
-pub struct BinaryOpException {
+#[derive(ViolationMetadata)]
+pub(crate) struct BinaryOpException {
     op: BoolOp,
 }
 
