@@ -3,7 +3,7 @@ use itertools::Itertools;
 use ruff_python_ast::{self as ast, CmpOp, Expr};
 
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_text_size::Ranged;
 
 use crate::checkers::ast::Checker;
@@ -40,8 +40,8 @@ use crate::checkers::ast::Checker;
 /// - [Python documentation: Truth Value Testing](https://docs.python.org/3/library/stdtypes.html#truth-value-testing)
 ///
 /// [#4282]: https://github.com/astral-sh/ruff/issues/4282
-#[violation]
-pub struct CompareToEmptyString {
+#[derive(ViolationMetadata)]
+pub(crate) struct CompareToEmptyString {
     existing: String,
     replacement: String,
 }
