@@ -1,13 +1,13 @@
 use ruff_diagnostics::Violation;
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 
 /// ## What it does
 /// Checks for variables defined in `for`, `try`, `with` statements
 /// that redefine function parameters.
 ///
 /// ## Why is this bad?
-/// Redefined variable can cause unexpected behavior because of overridden function parameter.
-/// If nested functions are declared, inner function's body can override outer function's parameter.
+/// Redefined variables can cause unexpected behavior because of overridden function parameters.
+/// If nested functions are declared, an inner function's body can override an outer function's parameters.
 ///
 /// ## Example
 /// ```python
@@ -22,11 +22,15 @@ use ruff_macros::{derive_message_formats, violation};
 ///     for inner_host_id, host in [[12.13, "Venus"], [14.15, "Mars"]]:
 ///         print(host_id, inner_host_id, host)
 /// ```
+///
+/// ## Options
+/// - `lint.dummy-variable-rgx`
+///
 /// ## References
 /// - [Pylint documentation](https://pylint.readthedocs.io/en/latest/user_guide/messages/refactor/redefined-argument-from-local.html)
 
-#[violation]
-pub struct RedefinedArgumentFromLocal {
+#[derive(ViolationMetadata)]
+pub(crate) struct RedefinedArgumentFromLocal {
     pub(crate) name: String,
 }
 
