@@ -1,5 +1,5 @@
 use ruff_diagnostics::{Diagnostic, Edit, Fix, FixAvailability, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast as ast;
 use ruff_python_semantic::analyze::function_type;
 use ruff_python_semantic::Scope;
@@ -42,8 +42,8 @@ use crate::importer::ImportRequest;
 /// ## Fix safety
 /// This rule's fix is marked as unsafe, as migrating from `@singledispatch` to
 /// `@singledispatchmethod` may change the behavior of the code.
-#[violation]
-pub struct SingledispatchMethod;
+#[derive(ViolationMetadata)]
+pub(crate) struct SingledispatchMethod;
 
 impl Violation for SingledispatchMethod {
     const FIX_AVAILABILITY: FixAvailability = FixAvailability::Sometimes;
