@@ -1,7 +1,7 @@
 use std::fmt;
 
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast::helpers::is_const_true;
 use ruff_python_ast::{self as ast, Expr};
 use ruff_text_size::Ranged;
@@ -53,8 +53,8 @@ use crate::rules::pylint::helpers::type_param_name;
 /// - [Python documentation: `typing` — Support for type hints](https://docs.python.org/3/library/typing.html)
 /// - [PEP 483 – The Theory of Type Hints: Covariance and Contravariance](https://peps.python.org/pep-0483/#covariance-and-contravariance)
 /// - [PEP 484 – Type Hints: Covariance and contravariance](https://peps.python.org/pep-0484/#covariance-and-contravariance)
-#[violation]
-pub struct TypeBivariance {
+#[derive(ViolationMetadata)]
+pub(crate) struct TypeBivariance {
     kind: VarKind,
     param_name: Option<String>,
 }
@@ -101,24 +101,25 @@ pub(crate) fn type_bivariance(checker: &mut Checker, value: &Expr) {
     };
 
     if is_const_true(covariant) && is_const_true(contravariant) {
-        let Some(kind) = checker
-            .semantic()
-            .resolve_call_path(func)
-            .and_then(|call_path| {
-                if checker
-                    .semantic()
-                    .match_typing_call_path(&call_path, "ParamSpec")
-                {
-                    Some(VarKind::ParamSpec)
-                } else if checker
-                    .semantic()
-                    .match_typing_call_path(&call_path, "TypeVar")
-                {
-                    Some(VarKind::TypeVar)
-                } else {
-                    None
-                }
-            })
+        let Some(kind) =
+            checker
+                .semantic()
+                .resolve_qualified_name(func)
+                .and_then(|qualified_name| {
+                    if checker
+                        .semantic()
+                        .match_typing_qualified_name(&qualified_name, "ParamSpec")
+                    {
+                        Some(VarKind::ParamSpec)
+                    } else if checker
+                        .semantic()
+                        .match_typing_qualified_name(&qualified_name, "TypeVar")
+                    {
+                        Some(VarKind::TypeVar)
+                    } else {
+                        None
+                    }
+                })
         else {
             return;
         };
