@@ -152,15 +152,18 @@ fn enumerate_items<'a>(
     };
 
     // If the `enumerate` call has a non-zero `start`, don't omit.
-    if !arguments.find_argument("start", 1).map_or(true, |expr| {
-        matches!(
-            expr,
-            Expr::NumberLiteral(ast::ExprNumberLiteral {
-                value: Number::Int(Int::ZERO),
-                ..
-            })
-        )
-    }) {
+    if !arguments
+        .find_argument_value("start", 1)
+        .map_or(true, |expr| {
+            matches!(
+                expr,
+                Expr::NumberLiteral(ast::ExprNumberLiteral {
+                    value: Number::Int(Int::ZERO),
+                    ..
+                })
+            )
+        })
+    {
         return None;
     }
 
