@@ -1,7 +1,7 @@
 use ruff_python_ast::Expr;
 
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_text_size::Ranged;
 
 use crate::checkers::ast::Checker;
@@ -28,8 +28,8 @@ use crate::rules::pylint::helpers::in_dunder_method;
 ///
 /// ## References
 /// - [CodeQL: `py-init-method-is-generator`](https://codeql.github.com/codeql-query-help/python/py-init-method-is-generator/)
-#[violation]
-pub struct YieldInInit;
+#[derive(ViolationMetadata)]
+pub(crate) struct YieldInInit;
 
 impl Violation for YieldInInit {
     #[derive_message_formats]
