@@ -1,5 +1,5 @@
 use ruff_diagnostics::{Diagnostic, Violation};
-use ruff_macros::{derive_message_formats, violation};
+use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast::visitor::{self, Visitor};
 use ruff_python_ast::{self as ast, Expr};
 use ruff_python_codegen::Generator;
@@ -35,8 +35,8 @@ use super::super::helpers::{find_file_opens, FileOpen};
 /// ## References
 /// - [Python documentation: `Path.read_bytes`](https://docs.python.org/3/library/pathlib.html#pathlib.Path.read_bytes)
 /// - [Python documentation: `Path.read_text`](https://docs.python.org/3/library/pathlib.html#pathlib.Path.read_text)
-#[violation]
-pub struct ReadWholeFile {
+#[derive(ViolationMetadata)]
+pub(crate) struct ReadWholeFile {
     filename: SourceCodeSnippet,
     suggestion: SourceCodeSnippet,
 }
@@ -53,12 +53,17 @@ impl Violation for ReadWholeFile {
 /// FURB101
 pub(crate) fn read_whole_file(checker: &mut Checker, with: &ast::StmtWith) {
     // `async` check here is more of a precaution.
-    if with.is_async || !checker.semantic().is_builtin("open") {
+    if with.is_async {
         return;
     }
 
     // First we go through all the items in the statement and find all `open` operations.
-    let candidates = find_file_opens(with, checker.semantic(), true);
+    let candidates = find_file_opens(
+        with,
+        checker.semantic(),
+        true,
+        checker.settings.target_version,
+    );
     if candidates.is_empty() {
         return;
     }
