@@ -6,6 +6,7 @@ pub(crate) use collection_literal_concatenation::*;
 pub(crate) use decimal_from_float_literal::*;
 pub(crate) use default_factory_kwarg::*;
 pub(crate) use explicit_f_string_type_conversion::*;
+pub(crate) use falsy_dict_get_fallback::*;
 pub(crate) use function_call_in_dataclass_default::*;
 pub(crate) use if_key_in_dict_del::*;
 pub(crate) use implicit_optional::*;
@@ -35,8 +36,10 @@ pub(crate) use test_rules::*;
 pub(crate) use unnecessary_cast_to_int::*;
 pub(crate) use unnecessary_iterable_allocation_for_first_element::*;
 pub(crate) use unnecessary_key_check::*;
+pub(crate) use unnecessary_literal_within_deque_call::*;
 pub(crate) use unnecessary_nested_literal::*;
 pub(crate) use unnecessary_regular_expression::*;
+pub(crate) use unnecessary_round::*;
 pub(crate) use unraw_re_pattern::*;
 pub(crate) use unsafe_markup_use::*;
 pub(crate) use unused_async::*;
@@ -54,6 +57,7 @@ mod confusables;
 mod decimal_from_float_literal;
 mod default_factory_kwarg;
 mod explicit_f_string_type_conversion;
+mod falsy_dict_get_fallback;
 mod function_call_in_dataclass_default;
 mod helpers;
 mod if_key_in_dict_del;
@@ -86,8 +90,10 @@ pub(crate) mod test_rules;
 mod unnecessary_cast_to_int;
 mod unnecessary_iterable_allocation_for_first_element;
 mod unnecessary_key_check;
+mod unnecessary_literal_within_deque_call;
 mod unnecessary_nested_literal;
 mod unnecessary_regular_expression;
+mod unnecessary_round;
 mod unraw_re_pattern;
 mod unsafe_markup_use;
 mod unused_async;
