@@ -7,10 +7,11 @@ use std::sync::{Mutex, OnceLock};
 
 use libfuzzer_sys::{fuzz_target, Corpus};
 
+use red_knot_python_semantic::lint::LintRegistry;
 use red_knot_python_semantic::types::check_types;
 use red_knot_python_semantic::{
     default_lint_registry, lint::RuleSelection, Db as SemanticDb, Program, ProgramSettings,
-    PythonVersion, SearchPathSettings,
+    PythonPlatform, PythonVersion, SearchPathSettings,
 };
 use ruff_db::files::{system_path_to_file, File, Files};
 use ruff_db::system::{DbWithTestSystem, System, SystemPathBuf, TestSystem};
@@ -40,7 +41,7 @@ impl TestDb {
             vendored: red_knot_vendored::file_system().clone(),
             events: std::sync::Arc::default(),
             files: Files::default(),
-            rule_selection: RuleSelection::from_registry(&default_lint_registry()).into(),
+            rule_selection: RuleSelection::from_registry(default_lint_registry()).into(),
         }
     }
 }
@@ -88,6 +89,10 @@ impl SemanticDb for TestDb {
     fn rule_selection(&self) -> &RuleSelection {
         &self.rule_selection
     }
+
+    fn lint_registry(&self) -> &LintRegistry {
+        default_lint_registry()
+    }
 }
 
 #[salsa::db]
@@ -112,6 +117,7 @@ fn setup_db() -> TestDb {
         &db,
         &ProgramSettings {
             python_version: PythonVersion::default(),
+            python_platform: PythonPlatform::default(),
             search_paths: SearchPathSettings::new(src_root),
         },
     )
