@@ -31,13 +31,16 @@ KNOWN_FORMATTING_VIOLATIONS = [
     "bad-quotes-multiline-string",
     "blank-line-after-decorator",
     "blank-line-before-class",
+    "blank-line-before-function",
     "blank-line-between-methods",
     "blank-lines-after-function-or-class",
     "blank-lines-before-nested-definition",
     "blank-lines-top-level",
+    "docstring-tab-indentation",
     "explicit-string-concatenation",
     "f-string-missing-placeholders",
-    "indent-with-spaces",
+    "incorrect-blank-line-after-class",
+    "incorrect-blank-line-before-class",
     "indentation-with-invalid-multiple",
     "line-too-long",
     "missing-trailing-comma",
@@ -58,14 +61,11 @@ KNOWN_FORMATTING_VIOLATIONS = [
     "multiple-spaces-before-operator",
     "multiple-statements-on-one-line-colon",
     "multiple-statements-on-one-line-semicolon",
-    "no-blank-line-before-function",
     "no-indented-block-comment",
     "no-return-argument-annotation-in-stub",
     "no-space-after-block-comment",
     "no-space-after-inline-comment",
     "non-empty-stub-body",
-    "one-blank-line-after-class",
-    "one-blank-line-before-class",
     "over-indentation",
     "over-indented",
     "pass-statement-stub-body",
